#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifdef HAVE_LIBASPELL
GList* get_speller_modules_list (const gchar *default_lang);
GList* get_suggestions_list (const gchar *lang, const gchar *s);
#endif

#ifdef ENCHANT_SUPPORTED
gboolean enchant_check (const gchar *word);
void enchant_init (void);
void enchant_done (void);
GList* enchant_get_suggestions_list (const gchar *s);
#endif